<?php
/**
 * @file
 * Contains \Drupal\merlinone\Form\MerlinOneConfigurationForm
 */

namespace Drupal\merlinone\Form;

use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class MerlinOneConfigurationForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'merlinone_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'merlinone.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('merlinone.settings');

    $form['mx_domain'] = [
      '#type' => 'textfield',
      '#title' => $this->t('MX Domain'),
      '#description' => $this->t('For example: <em>https://your-domain.merlinone.com</em>.'),
      '#default_value' => $config->get('mx_domain'),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $mx_domain = $form_state->getValue('mx_domain');
    if (!UrlHelper::isValid($mx_domain, TRUE)) {
      $form_state->setError($form['mx_domain'], $this->t('MX Domain is not valid'));
    }

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('merlinone.settings')
      ->set('mx_domain', $form_state->getValue('mx_domain'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}